getrandom_backend

Macro getrandom_backend 

macro_rules! getrandom_backend {
    () => { ... };
}
Defines the getrandom custom backend, which is an unsafe extern "Rust" symbol that fills a buffer from the hardware RNG registered by init_entropy!. This is what the SSH host key and the WiFi password use, so it must be a true and secure source of randomness.