init_entropy

Macro init_entropy 

macro_rules! init_entropy {
    ($peripherals:expr) => { ... };
}
Creates the boot entropy source and registers the hardware RNG with getrandom.

This is a convenience macro that allows creating the source without having to specify the features manually.